@@ -109,11 +109,10 @@ class FourStore(RDFLib):
         assert isinstance(g, _Graph)
         ident = get_identifier(k)
         cursor = self.store.cursor()
-        cursor.delete_model(ident)
-        cursor.add_model(g)
+        cursor.add_graph(g)
     def __delitem__(self, k):
         ident = get_identifier(k)
         cursor = self.store.cursor()
-        cursor.delete_model(ident)
+        cursor.delete_graph(ident)
     def query(self, *av, **kw):
         return self.store.query(*av, **kw)
