@@ -148,8 +148,11 @@ def inference_rules(handler, network):
     for rule in rules:
         network.buildNetworkFromClause(rule)
     
-    from FuXi.DLP.DLNormalization import NormalFormReduction
-    dlp = network.setupDescriptionLogicProgramming(Graph(), addPDSemantics=True)
+    owl = handler.get(OWL[""][:-1])
+    if len(owl) == 0:
+        for owl in rdf_data():
+            pass
+    dlp = network.setupDescriptionLogicProgramming(owl, addPDSemantics=True)
     return list(rules) + dlp
 
 # definition of an Infix operator class
